@@ -39,12 +39,19 @@ class StreamModel : public QAbstractTableModel
 
         int rowCount(const QModelIndex &parent = QModelIndex()) const;
         int columnCount(const QModelIndex &parent = QModelIndex()) const;
+
         Qt::ItemFlags flags(const QModelIndex &index) const;
         QVariant data(const QModelIndex &index, int role) const;
         bool setData(const QModelIndex &index, const QVariant &value,
             int role = Qt::EditRole);
         QVariant headerData(int section, Qt::Orientation orientation,
             int role = Qt::DisplayRole) const;
+
+        QStringList mimeTypes() const;
+        QMimeData* mimeData(const QModelIndexList &indexes) const;
+        bool dropMimeData(const QMimeData *data, Qt::DropAction action,
+            int row, int column, const QModelIndex &parent);
+
         bool insert(int row, QList<Stream*> &streams);
         bool insertRows (int row, int count,
             const QModelIndex & parent = QModelIndex());
