@@ -354,6 +354,11 @@ QVariant Ip6Protocol::fieldData(int index, FieldAttrib attrib,
                 case FieldName:            
                     return QString("Source");
                 case FieldValue:
+                {
+                    QVariant v;
+                    v.setValue(src);
+                    return v;
+                }
                 case FieldFrameValue:
                 case FieldTextValue:
                 {
@@ -412,6 +417,11 @@ QVariant Ip6Protocol::fieldData(int index, FieldAttrib attrib,
                 case FieldName:            
                     return QString("Destination");
                 case FieldValue:
+                {
+                    QVariant v;
+                    v.setValue(dst);
+                    return v;
+                }
                 case FieldFrameValue:
                 case FieldTextValue:
                 {
@@ -594,6 +604,14 @@ bool Ip6Protocol::setFieldData(int index, const QVariant &value,
         }
         case ip6_srcAddress:
         {
+            if (value.typeName() == QString("UInt128")) {
+                UInt128 addr = value.value<UInt128>();
+                data.set_src_addr_hi(addr.hi64());
+                data.set_src_addr_lo(addr.lo64());
+                isOk = true;
+                break;
+            }
+
             Q_IPV6ADDR addr = QHostAddress(value.toString()).toIPv6Address();
             quint64 x;
 
@@ -616,10 +634,19 @@ bool Ip6Protocol::setFieldData(int index, const QVariant &value,
                 | (quint64(addr[14]) <<  8)
                 | (quint64(addr[15]) <<  0);
             data.set_src_addr_lo(x);
+            isOk = true;
             break;
         }
         case ip6_dstAddress:
         {
+            if (value.typeName() == QString("UInt128")) {
+                UInt128 addr = value.value<UInt128>();
+                data.set_dst_addr_hi(addr.hi64());
+                data.set_dst_addr_lo(addr.lo64());
+                isOk = true;
+                break;
+            }
+
             Q_IPV6ADDR addr = QHostAddress(value.toString()).toIPv6Address();
             quint64 x;
 
@@ -642,6 +669,7 @@ bool Ip6Protocol::setFieldData(int index, const QVariant &value,
                 | (quint64(addr[14]) <<  8)
                 | (quint64(addr[15]) <<  0);
             data.set_dst_addr_lo(x);
+            isOk = true;
             break;
         }
 
@@ -740,7 +768,7 @@ int Ip6Protocol::protocolFrameVariableCount() const
 }
 
 quint32 Ip6Protocol::protocolFrameCksum(int streamIndex, 
-        CksumType cksumType) const
+        CksumType cksumType, CksumFlags cksumFlags) const
 {
     if (cksumType == CksumIpPseudo)
     {
@@ -764,7 +792,8 @@ quint32 Ip6Protocol::protocolFrameCksum(int streamIndex,
 
         return qFromBigEndian((quint16) ~sum);
     }
-    return AbstractProtocol::protocolFrameCksum(streamIndex, cksumType);
+    return AbstractProtocol::protocolFrameCksum(
+                                streamIndex, cksumType, cksumFlags);
 }
 
 bool Ip6Protocol::hasErrors(QStringList *errors) const
