@@ -64,6 +64,11 @@ AbstractPort::~AbstractPort()
 
 void AbstractPort::init()
 {
+    if (interfaceInfo_) {
+        data_.set_speed(interfaceInfo_->speed);
+        data_.set_mtu(interfaceInfo_->mtu);
+    }
+
     if (deviceManager_)
         deviceManager_->createHostDevices();
 }    
@@ -256,7 +261,7 @@ int AbstractPort::updatePacketListSequential()
 
             switch (streamList_[i]->sendUnit())
             {
-            case OstProto::StreamControl::e_su_bursts:
+            case StreamBase::e_su_bursts:
                 burstSize = streamList_[i]->burstSize();
                 x = AbstractProtocol::lcm(frameVariableCount, burstSize);
                 n = ulong(burstSize * streamList_[i]->numBursts()) / x;
@@ -271,7 +276,7 @@ int AbstractPort::updatePacketListSequential()
                 }
                 loopDelay = ibg2;
                 break;
-            case OstProto::StreamControl::e_su_packets:
+            case StreamBase::e_su_packets:
                 x = frameVariableCount;
                 n = 2;
                 while (x < minPacketSetSize_) 
@@ -315,8 +320,10 @@ int AbstractPort::updatePacketListSequential()
             qDebug("npx2 = %llu", npx2);
             qDebug("npy2 = %llu\n", npy2);
 
-            if (n > 1)
+            if (n >= 1) {
                 loopNextPacketSet(x, n, 0, loopDelay);
+                qDebug("PacketSet: n = %lu, x = %lu", n, x);
+            }
             else if (n == 0)
                 x = 0;
 
@@ -333,10 +340,20 @@ int AbstractPort::updatePacketListSequential()
                 if (len <= 0)
                     continue;
 
+                // Create a packet set for 'y' with repeat = 1
+                if (j == x) {
+                    loopNextPacketSet(y, 1, 0, loopDelay);
+                    qDebug("PacketSet: n = 1, y = %lu", y);
+                }
+
                 qDebug("q(%d, %d) sec = %lu nsec = %lu",
                         i, j, sec, nsec);
 
-                appendToPacketList(sec, nsec, pktBuf_, len); 
+                if (!appendToPacketList(sec, nsec, pktBuf_, len)) {
+                    clearPacketList(); // don't leave it half baked/inconsitent
+                    packetListAttrib.errorFlags |= FrameValueAttrib::OutOfMemoryError;
+                    goto _out_of_memory;
+                }
 
                 if ((j > 0) && (((j+1) % burstSize) == 0))
                 {
@@ -364,10 +381,10 @@ int AbstractPort::updatePacketListSequential()
 
             switch(streamList_[i]->nextWhat())
             {
-                case ::OstProto::StreamControl::e_nw_stop:
+                case StreamBase::e_nw_stop:
                     goto _stop_no_more_pkts;
 
-                case ::OstProto::StreamControl::e_nw_goto_id:
+                case StreamBase::e_nw_goto_id:
                     /*! \todo (MED): define and use 
                     streamList_[i].d.control().goto_stream_id(); */
 
@@ -385,7 +402,7 @@ int AbstractPort::updatePacketListSequential()
                                 StreamBase::e_su_bursts ? ibg1 : ipg1);
                     goto _stop_no_more_pkts;
 
-                case ::OstProto::StreamControl::e_nw_goto_next:
+                case StreamBase::e_nw_goto_next:
                     break;
 
                 default:
@@ -397,6 +414,7 @@ int AbstractPort::updatePacketListSequential()
         } // if (stream is enabled)
     } // for (numStreams)
 
+_out_of_memory:
 _stop_no_more_pkts:
     isSendQueueDirty_ = false;
 
@@ -410,7 +428,8 @@ int AbstractPort::updatePacketListInterleaved()
     FrameValueAttrib packetListAttrib;
     int numStreams = 0;
     quint64 minGap = ULLONG_MAX;
-    quint64 duration = quint64(1e9);
+    quint64 duration = quint64(1e3);
+    QList<int> streamId;
     QList<quint64> ibg1, ibg2;
     QList<quint64> nb1, nb2;
     QList<quint64> ipg1, ipg2;
@@ -447,6 +466,8 @@ int AbstractPort::updatePacketListInterleaved()
         if (!streamList_[i]->isEnabled())
             continue;
 
+        streamId.append(i);
+
         double numBursts = 0;
         double numPackets = 0;
 
@@ -458,10 +479,12 @@ int AbstractPort::updatePacketListInterleaved()
         quint64 _ipg1 = 0, _ipg2 = 0;
         quint64 _np1 = 0, _np2 = 0;
 
+
         switch (streamList_[i]->sendUnit())
         {
-        case OstProto::StreamControl::e_su_bursts:
+        case StreamBase::e_su_bursts:
             numBursts = streamList_[i]->burstRate();
+            _burstSize = streamList_[i]->burstSize();
             if (streamList_[i]->burstRate() > 0)
             {
                 ibg = 1e9/double(streamList_[i]->burstRate());
@@ -469,11 +492,11 @@ int AbstractPort::updatePacketListInterleaved()
                 _ibg2 = quint64(floor(ibg));
                 _nb1 = quint64((ibg - double(_ibg2)) * double(numBursts));
                 _nb2 = quint64(numBursts) - _nb1;
-                _burstSize = streamList_[i]->burstSize();
             }
             break;
-        case OstProto::StreamControl::e_su_packets:
+        case StreamBase::e_su_packets:
             numPackets = streamList_[i]->packetRate();
+            _burstSize = 1;
             if (streamList_[i]->packetRate() > 0)
             {
                 ipg = 1e9/double(streamList_[i]->packetRate());
@@ -481,7 +504,6 @@ int AbstractPort::updatePacketListInterleaved()
                 _ipg2 = quint64(floor(ipg));
                 _np1 = quint64((ipg - double(_ipg2)) * double(numPackets));
                 _np2 = quint64(numPackets) - _np1;
-                _burstSize = 1;
             }
             break;
         default:
@@ -565,9 +587,23 @@ int AbstractPort::updatePacketListInterleaved()
         numStreams++;
     } // for i
 
+    // handle burst/packet rate = 0
+    // i.e. send all streams "simultaneously" as fast as possible
+    // as a result all streams will be at the same rate e.g. for 2 streams,
+    // it would 50% each; for 3 streams - all at 33.3% and so on
+    if (minGap == ULLONG_MAX) {
+        minGap = 1;
+        duration = 1;
+    }
+
     qDebug("minGap   = %llu", minGap);
     qDebug("duration = %llu", duration);
 
+    if (duration < minGap*100) {
+        duration = minGap*100;
+        qDebug("increase duration to %llu for better accuracy", duration);
+    }
+
     uchar* buf;
     int len;
     quint64 durSec = duration/ulong(1e9);
@@ -590,7 +626,7 @@ int AbstractPort::updatePacketListInterleaved()
                 {
                     FrameValueAttrib attrib;
                     buf = pktBuf_;
-                    len = streamList_[i]->frameValue(pktBuf_, sizeof(pktBuf_), 
+                    len = streamList_[streamId.at(i)]->frameValue(pktBuf_, sizeof(pktBuf_),
                             pktCount[i], &attrib);
                     packetListAttrib += attrib;
                 }
@@ -604,7 +640,11 @@ int AbstractPort::updatePacketListInterleaved()
                     continue;
 
                 qDebug("q(%d) sec = %llu nsec = %llu", i, sec, nsec);
-                appendToPacketList(sec, nsec, buf, len); 
+                if (!appendToPacketList(sec, nsec, buf, len)) {
+                    clearPacketList(); // don't leave it half baked/inconsitent
+                    packetListAttrib.errorFlags |= FrameValueAttrib::OutOfMemoryError;
+                    goto _out_of_memory;
+                }
                 lastPktTxSec = sec;
                 lastPktTxNsec = nsec;
 
@@ -636,15 +676,19 @@ int AbstractPort::updatePacketListInterleaved()
         }
     } while ((sec < durSec) || (nsec < durNsec));
 
-    qint64 delaySec = durSec - lastPktTxSec;
-    qint64 delayNsec = durNsec - lastPktTxNsec;
-    while (delayNsec < 0)
     {
-        delayNsec += long(1e9);
-        delaySec--;
+        qint64 delaySec = durSec - lastPktTxSec;
+        qint64 delayNsec = durNsec - lastPktTxNsec;
+        while (delayNsec < 0)
+        {
+            delayNsec += long(1e9);
+            delaySec--;
+        }
+        qDebug("loop Delay = %lld/%lld", delaySec, delayNsec);
+        setPacketListLoopMode(true, delaySec, delayNsec);
     }
-    qDebug("loop Delay = %lld/%lld", delaySec, delayNsec);
-    setPacketListLoopMode(true, delaySec, delayNsec); 
+
+_out_of_memory:
     isSendQueueDirty_ = false;
 
     qDebug("PacketListAttrib = %x",
@@ -688,6 +732,9 @@ void AbstractPort::stats(PortStats *stats)
 
 void AbstractPort::streamStats(uint guid, OstProto::StreamStatsList *stats)
 {
+    // In case stats are being maintained elsewhere
+    updateStreamStats();
+
     if (streamStats_.contains(guid))
     {
         StreamStatsTuple sst = streamStats_.value(guid);
@@ -696,6 +743,8 @@ void AbstractPort::streamStats(uint guid, OstProto::StreamStatsList *stats)
         s->mutable_stream_guid()->set_id(guid);
         s->mutable_port_id()->set_id(id());
 
+        s->set_tx_duration(lastTransmitDuration());
+
         s->set_tx_pkts(sst.tx_pkts);
         s->set_tx_bytes(sst.tx_bytes);
         s->set_rx_pkts(sst.rx_pkts);
@@ -705,8 +754,12 @@ void AbstractPort::streamStats(uint guid, OstProto::StreamStatsList *stats)
 
 void AbstractPort::streamStatsAll(OstProto::StreamStatsList *stats)
 {
+    // In case stats are being maintained elsewhere
+    updateStreamStats();
+
     // FIXME: change input param to a non-OstProto type and/or have
     // a getFirst/Next like API?
+    double txDur = lastTransmitDuration();
     StreamStatsIterator i(streamStats_);
     while (i.hasNext())
     {
@@ -717,6 +770,8 @@ void AbstractPort::streamStatsAll(OstProto::StreamStatsList *stats)
         s->mutable_stream_guid()->set_id(i.key());
         s->mutable_port_id()->set_id(id());
 
+        s->set_tx_duration(txDur);
+
         s->set_tx_pkts(sst.tx_pkts);
         s->set_tx_bytes(sst.tx_bytes);
         s->set_rx_pkts(sst.rx_pkts);
