@@ -110,6 +110,7 @@ public:
     virtual void startTransmit() = 0;
     virtual void stopTransmit() = 0;
     virtual bool isTransmitOn() = 0;
+    virtual double lastTransmitDuration() = 0;
 
     virtual void startCapture() = 0;
     virtual void stopCapture() = 0;
@@ -124,6 +125,9 @@ public:
     void streamStatsAll(OstProto::StreamStatsList *stats);
     void resetStreamStats(uint guid);
     void resetStreamStatsAll();
+    virtual void updateStreamStats() {
+        // subclasses may implement - if required
+    }
 
     DeviceManager* deviceManager();
     virtual void startDeviceEmulation() = 0;
