@@ -32,6 +32,10 @@ public:
     Drone(QObject *parent = 0);
     ~Drone();
     bool init();
+    MyService* rpcService();
+
+private slots:
+    void onNewVersion(QString version);
 
 private:
     RpcServer               *rpcServer;
