@@ -22,15 +22,14 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>
 #include "../common/protocolmanager.h"
 #include "params.h"
 #include "settings.h"
+#include "turbo.h"
 
 #include <google/protobuf/stubs/common.h>
 
 #include <QCoreApplication>
 #include <QFile>
 
-#ifdef Q_OS_UNIX
 #include <signal.h>
-#endif
 
 extern ProtocolManager *OstProtocolManager;
 extern char *version;
@@ -45,6 +44,8 @@ void NoMsgHandler(QtMsgType type, const QMessageLogContext &context,
 
 void cleanup(int /*signum*/)
 {
+    fprintf(stderr, "\nCleaning up (may take a few seconds) ... ");
+    fflush(stderr);
     QCoreApplication::instance()->exit(-1);
 }
 
@@ -58,6 +59,9 @@ int main(int argc, char *argv[])
 
     appParams.parseCommandLine(argc, argv);
 
+    fprintf(stderr, "Starting (will take a few seconds) ...\n");
+    fflush(stderr);
+
 #ifdef QT_NO_DEBUG
     if (appParams.optLogsDisabled())
         qInstallMessageHandler(NoMsgHandler);
@@ -80,6 +84,12 @@ int main(int argc, char *argv[])
                                     app.applicationName().toLower());
     qDebug("Settings: %s", qPrintable(appSettings->fileName()));
 
+    if (!initTurbo())
+    {
+        exitCode = 1;
+        goto _exit2;
+    }
+
     drone = new Drone();
     OstProtocolManager = new ProtocolManager();
 
@@ -100,6 +110,11 @@ int main(int argc, char *argv[])
         qDebug("Failed to install SIGTERM handler. Cleanup may not happen!!!");
     if (sigaction(SIGINT, &sa, NULL))
         qDebug("Failed to install SIGINT handler. Cleanup may not happen!!!");
+#elif defined(Q_OS_WIN32)
+    if (signal(SIGTERM, cleanup) == SIG_ERR)
+        qDebug("Failed to install SIGTERM handler. Cleanup may not happen!!!");
+    if (signal(SIGINT, cleanup) == SIG_ERR)
+        qDebug("Failed to install SIGINT handler. Cleanup may not happen!!!");
 #endif
 
     exitCode = app.exec();
@@ -108,8 +123,12 @@ _exit:
     delete drone;
     delete OstProtocolManager;
 
+_exit2:
     google::protobuf::ShutdownProtobufLibrary();
 
+    fprintf(stderr, "done.\n");
+    fflush(stderr);
+
     return exitCode;
 } 
 
