@@ -39,6 +39,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>
 #include "portmanager.h"
 
 #include <QStringList>
+#include <QThread>
 
 
 extern Drone *drone;
@@ -425,6 +426,10 @@ void MyService::startTransmit(::google::protobuf::RpcController* /*controller*/,
 
     qDebug("In %s", __PRETTY_FUNCTION__);
 
+    // XXX: stream stats uses port tx duration to calculate per stream
+    // rates; tx duration is for the last tx run only - so stream stats
+    // should also correspond to the last run only.
+    // Hence clear stream stats before Tx
     for (int i = 0; i < request->port_id_size(); i++)
     {
         int portId;
@@ -441,6 +446,7 @@ void MyService::startTransmit(::google::protobuf::RpcController* /*controller*/,
         portLock[portId]->lockForWrite();
         if (portInfo[portId]->isDirty())
             frameError = portInfo[portId]->updatePacketList();
+        portInfo[portId]->resetStreamStatsAll();
         portInfo[portId]->startTransmit();
         portLock[portId]->unlock();
         if (frameError) {
@@ -1168,8 +1174,12 @@ void MyService::resolveDeviceNeighbors(
         response->set_status(OstProto::Ack::kRpcError);
         response->set_notes(notes.toStdString());
     }
-    else
+    else {
+        // XXX: allow time for ARP/ND to finish; if more time is required,
+        // the client should wait/check before invoking build()
+        QThread::msleep(500);
         response->set_status(OstProto::Ack::kRpcSuccess);
+    }
     done->Run();
 }
 
@@ -1249,6 +1259,9 @@ QString MyService::frameValueErrorNotes(int portId, int error)
     QString pfx = QString("Port %1: ").arg(portId);
     auto errorFlags = static_cast<FrameValueAttrib::ErrorFlags>(error);
 
+    if (errorFlags & FrameValueAttrib::OutOfMemoryError)
+        return pfx + "Error building packet buffers - out of buffer memory\n";
+
     // If smac resolve fails, dmac will always fail - so check that first
     // and report only that so as not to confuse users (they may not realize
     // that without a source device, we have no ARP table to lookup for dmac)
