@@ -17,7 +17,7 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>
 */
 
-#include "pcaptransmitter.h"
+#include "pcaptxthread.h"
 
 #include "statstuple.h"
 #include "timestamp.h"
@@ -109,6 +109,11 @@ void PcapTxThread::clearPacketList()
 void PcapTxThread::loopNextPacketSet(qint64 size, qint64 repeats,
         long repeatDelaySec, long repeatDelayNsec)
 {
+    // Since we create implicit packetset for this case, skip
+    // This case => Packet set for y when x = 0 or n==1 in n*x+y
+    if (repeats == 1)
+        return;
+
     currentPacketSequence_ = new PacketSequence(trackStreamStats_);
     currentPacketSequence_->repeatCount_ = repeats;
     currentPacketSequence_->usecDelay_ = repeatDelaySec * long(1e6)
@@ -243,10 +248,13 @@ void PcapTxThread::run()
     const int kSyncTransmit = 1;
     int i;
     long overHead = 0; // overHead should be negative or zero
+    TimeStamp startTime, endTime;
 
     qDebug("packetSequenceList_.size = %d", packetSequenceList_.size());
-    if (packetSequenceList_.size() <= 0)
-        goto _exit;
+    if (packetSequenceList_.size() <= 0) {
+        lastTxDuration_ = 0.0;
+        goto _exit2;
+    }
 
     for(i = 0; i < packetSequenceList_.size(); i++) {
         qDebug("sendQ[%d]: rptCnt = %d, rptSz = %d, usecDelay = %ld", i,
@@ -260,6 +268,7 @@ void PcapTxThread::run()
 
     lastStats_ = *stats_; // used for stream stats
 
+    getTimeStamp(&startTime);
     state_ = kRunning;
     i = 0;
     while (i < packetSequenceList_.size())
@@ -348,6 +357,13 @@ _restart:
     }
 
 _exit:
+    getTimeStamp(&endTime);
+    lastTxDuration_ = udiffTimeStamp(&startTime, &endTime)/1e6;
+
+_exit2:
+    qDebug("Tx duration = %fs", lastTxDuration_);
+    //Q_ASSERT(lastTxDuration_ >= 0);
+
     if (trackStreamStats_)
         updateStreamStats();
 
@@ -388,6 +404,11 @@ bool PcapTxThread::isRunning()
     return (state_ == kRunning);
 }
 
+double PcapTxThread::lastTxDuration()
+{
+    return lastTxDuration_;
+}
+
 int PcapTxThread::sendQueueTransmit(pcap_t *p,
         pcap_send_queue *queue, long &overHead, int sync)
 {
